@@ -50,6 +50,7 @@ class Repl(Cmd):
         for name, cmd in commands.items():
             setattr(self, f'do_{name}', safe(cmd, target))
         self.modules = target.modules.items.keys()
+        self.managers = target.managers.items.keys()
         super().__init__()
 
     def do_help(self, cmd):
@@ -65,9 +66,13 @@ class Repl(Cmd):
         print()
 
     def default(self, line):
-        module = line.split()[0]
-        if module in self.modules:
+        what = line.split()[0]
+        if what in self.modules:
             self.onecmd(f'deploy {line}')
+        elif '.' in what:
+            manager, _, command = what.partition('.')
+            if manager in self.managers:
+                self.onecmd(f'manage {line}')
         else:
             self.onecmd(f'run {line}')
 
